'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.LEAD_CLASS = exports.CLOSING_PARENS = exports.OPENING_PARENS = undefined;
exports.isValidCandidate = isValidCandidate;

var _common = require('./common');

var _utf = require('./utf-8.common');

// Copy-pasted from `PhoneNumberMatcher.js`.

var OPENING_PARENS = exports.OPENING_PARENS = '(\\[\uFF08\uFF3B';
var CLOSING_PARENS = exports.CLOSING_PARENS = ')\\]\uFF09\uFF3D';

var LEAD_CLASS = exports.LEAD_CLASS = '[' + OPENING_PARENS + _common.PLUS_CHARS + ']';

// Punctuation that may be at the start of a phone number - brackets and plus signs.
var LEAD_CLASS_LEADING = new RegExp('^' + LEAD_CLASS);

function isValidCandidate(candidate, offset, text) {
	// If the candidate is not at the start of the text,
	// and does not start with phone-number punctuation,
	// check the previous character.
	if (offset > 0 && !LEAD_CLASS_LEADING.test(candidate)) {
		var previousChar = text[offset - 1];
		// We return null if it is a latin letter or an invalid punctuation symbol.
		if ((0, _utf.isInvalidPunctuationSymbol)(previousChar) || (0, _utf.isLatinLetter)(previousChar)) {
			return false;
		}
	}

	var lastCharIndex = offset + candidate.length;
	if (lastCharIndex < text.length) {
		var nextChar = text[lastCharIndex];
		if ((0, _utf.isInvalidPunctuationSymbol)(nextChar) || (0, _utf.isLatinLetter)(nextChar)) {
			return false;
		}
	}

	return true;
}
//# sourceMappingURL=findNumbers.common.js.map